@@ -1,8 +1,9 @@
 """Cut a mesh with another mesh"""
 from vedo import *
 
-embryo = load(dataurl+"embryo.tif").isosurface(30).normalize()
-txt = Text2D(__doc__, c='b', bg='lb')
+settings.tiffOrientationType = 4 # data origin is bottom-left
+
+embryo = Volume(dataurl+"embryo.tif").isosurface(30).normalize()
 
 # mesh used to cut:
 msh = Ellipsoid().scale(0.4).pos(2.8, 1.5, 1.5).wireframe()
@@ -11,4 +12,4 @@ msh = Ellipsoid().scale(0.4).pos(2.8, 1.5, 1.5).wireframe()
 cutembryo = embryo.clone().cutWithMesh(msh).c("gold").bc("t")
 
 show(embryo, msh,    at=0, N=2, axes=1, viewup="z")
-show(cutembryo, txt, at=1, interactive=1)
+show(cutembryo, __doc__, at=1, interactive=True).close()
