@@ -7,7 +7,7 @@ import numpy as np
 from vedo import *
 
 # declare the class instance
-vp = Plotter()
+plt = Plotter()
 
 # draw 500 fit lines superimposed and very transparent
 for i in range(500):
@@ -18,16 +18,16 @@ for i in range(500):
     data = np.stack((x,y,z), axis=1)
     data += np.random.normal(size=data.shape) * 0.8  # add gauss noise
 
-    vp += fitLine(data).lw(4).alpha(0.04).c("violet")  # fit a line
+    plt += fitLine(data).lw(4).alpha(0.04).c("violet")  # fit a line
 
 # 'data' still contains the last iteration points
-vp += Points(data, r=10, c="yellow")
+plt += Points(data, r=10, c="yellow")
 
-print("Line 0 Fit slope = ", vp.actors[0].slope)
+print("Line 0 Fit slope = ", plt.actors[0].slope)
 
 plane = fitPlane(data).c("green4")  # fit a plane
 print("Plane Fit normal =", plane.normal)
 
-vp += [plane, __doc__]
+plt += [plane, __doc__]
 
-vp.show(axes=1)
+plt.show(axes=1).close()
