@@ -11,6 +11,6 @@ pts = Points([sc[10], sc[15], sc[129], sc[165]], r=12)
 
 #cut loop region identified by the points
 scut = s.clone().cutWithPointLoop(pts, invert=False)
-scut.c('blue').alpha(0.7).lw(0).scale(1.03)
+scut.c('blue',0.7).lw(0).scale(1.03)
 
 show(s, pts, scut, __doc__, axes=1)
