@@ -21,7 +21,7 @@ ptsource, pttarget = [], []
 for pt in pts:
     ptold = pt + np.random.randn(3) * 0.02
     ptsource.append(ptold)
-    ptnew = ptold + [0, 0, np.random.randn(1) * 0.10]  # move in z
+    ptnew = ptold + [0, 0, np.random.randn(1) * 0.1]  # move in z
     pttarget.append(ptnew)
 
 warped = mesh.thinPlateSpline(ptsource, pttarget)
@@ -30,4 +30,4 @@ warped.alpha(0.2).color("b")
 apts = Points(ptsource, r=5, c="r")
 arrs = Arrows(ptsource, pttarget, c='k')
 
-show(warped, apts, arrs, __doc__, axes=9, viewup="z")
+show(warped, apts, arrs, __doc__, axes=9, viewup="z").close()
