@@ -21,4 +21,4 @@ pts = noise1.tolist() + noise2.tolist() + noise3.tolist() + noise4.tolist()
 # find back their identity through clustering
 cl = cluster(pts, radius=0.1)  # returns a vtkAssembly
 
-show(cl, __doc__, axes=1, viewup='z')
+show(cl, __doc__, axes=1, viewup='z').close()
