@@ -2,7 +2,7 @@
 the vertices of a mesh to its cells"""
 from vedo import *
 
-mesh1 = load(dataurl+'icosahedron.vtk').lineWidth(0.1)
+mesh1 = Mesh(dataurl+'icosahedron.vtk').lineWidth(0.1)
 
 doc = Text2D(__doc__, pos="bottom-left")
 
@@ -15,4 +15,4 @@ msg2 = Text2D("..is interpolated to cells.", pos="top-center")
 mesh2 = mesh1.clone(deep=False).mapPointsToCells()
 
 show(mesh1, msg1, doc, at=0, N=2, axes=11, viewup="z")
-show(mesh2, msg2,      at=1, interactive=True)
+show(mesh2, msg2,      at=1, interactive=True).close()
