@@ -12,5 +12,5 @@ r12 = Ribbon(l1, l2, res=(200,5)).alpha(0.5)
 show(r12, t1, t2, __doc__, at=0, N=2, axes=1, viewup="z")
 
 r1  = Ribbon(l1, width=0.1).alpha(0.5).color('orange')
-show(r1, t1, "..or along a single line", at=1, interactive=True)
+show(r1, t1, "..or along a single line", at=1, interactive=True).close()
 
