@@ -1,8 +1,8 @@
 """Make a static 2D copy of a mesh
 and place it in the rendering window"""
-from vedo import load, dataurl, show
+from vedo import Mesh, dataurl, show
 
-s = load(dataurl+'man.vtk').rotateZ(20).rotateX(-70).scale(0.2).c('darkgreen', 0.3)
+s = Mesh(dataurl+'man.vtk').rotateZ(20).rotateX(-70).scale(0.2).c('darkgreen', 0.3)
 
 # Make a 2D snapshot of a 3D mesh
 # The coordinate system options are
@@ -16,5 +16,5 @@ s = load(dataurl+'man.vtk').rotateZ(20).rotateX(-70).scale(0.2).c('darkgreen', 0
 
 s2d = s.clone2D(pos=[0.4,0.4], coordsys=4, c='r', alpha=1)
 
-show(s, s2d, __doc__, axes=1)
+show(s, s2d, __doc__, axes=1).close()
 
