@@ -1,17 +1,13 @@
 import vtk
 import numpy
 import os
-
 import vedo.colors as colors
 from vedo.mesh import Mesh
 from vedo.pointcloud import Points
-
 from vedo.volume import Volume
 import vedo.settings as settings
-# import vedo.addons as addons
 import vedo.shapes as shapes
 import vedo.utils as utils
-from vtk.util.numpy_support import vtk_to_numpy
 
 __all__ = []
 
@@ -199,11 +195,11 @@ def getNotebookBackend(actors2show, zoom, viewup):
                 settings.notebook_plotter += kobj
 
             #####################################################################Points
-            elif isinstance(ia, Points) or ia.NPoints() == ia.NCells():
+            elif isinstance(ia, Points):
                 # print('Points', ia.name, ia.N())
                 kcols=[]
                 if color_attribute is not None:
-                    scals = vtk_to_numpy(vtkscals)
+                    scals = utils.vtk2numpy(vtkscals)
                     kcols = k3d.helpers.map_colors(scals, kcmap,
                                                    [scals_min,scals_max]).astype(numpy.uint32)
                 # sqsize = numpy.sqrt(numpy.dot(sizes, sizes))
@@ -227,7 +223,7 @@ def getNotebookBackend(actors2show, zoom, viewup):
 
                 # kcols=[]
                 # if color_attribute is not None:
-                #     scals = vtk_to_numpy(vtkscals)
+                #     scals = utils.vtk2numpy(vtkscals)
                 #     kcols = k3d.helpers.map_colors(scals, kcmap,
                 #                                    [scals_min,scals_max]).astype(numpy.uint32)
 
@@ -263,7 +259,7 @@ def getNotebookBackend(actors2show, zoom, viewup):
     ####################################################################################
     elif 'ipyvtk' in settings.notebookBackend and hasattr(vp, 'window') and vp.window:
 
-        from ipyvtk_simple.viewer import ViewInteractiveWidget
+        from ipyvtklink.viewer import ViewInteractiveWidget
         vp.renderer.ResetCamera()
         settings.notebook_plotter = ViewInteractiveWidget(vp.window)
 
