@@ -2,9 +2,7 @@ import numpy as np
 import vtk
 import vedo
 import vedo.colors as colors
-import vedo.settings as settings
 import vedo.utils as utils
-from vtk.util.numpy_support import numpy_to_vtk, vtk_to_numpy, numpy_to_vtkIdTypeArray
 
 __doc__ = (
     """Base classes. Do not instantiate these."""
@@ -19,11 +17,9 @@ __all__ = [
            "probeLine",
            "probePlane",
            "streamLines",
-           ]
-
+]
 
 ###############################################################################
-# classes
 class Base3DProp(object):
 
     def __init__(self):
@@ -222,61 +218,79 @@ class Base3DProp(object):
                            self.shadow.GetProperty().GetOpacity())
         return self
 
-    def rotateX(self, angle, rad=False):
-        """Rotate around x-axis. If angle is in radians set ``rad=True``."""
+    def rotateX(self, angle, rad=False, locally=False):
+        """Rotate around x-axis. If angle is in radians set ``rad=True``.
+
+        :param bool locally: ignore previous transformations. Rotate around object local origin.
+        """
         if rad:
             angle *= 180 / np.pi
-        T = vtk.vtkTransform()
-        self.ComputeMatrix()
-        T.SetMatrix(self.GetMatrix())
-        T.PostMultiply()
-        T.RotateX(angle)
-        self.SetOrientation(T.GetOrientation())
-        self.SetPosition(T.GetPosition())
-        if self.trail:
-            self.updateTrail()
-        if self.shadow:
-            self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                           self.shadow.GetProperty().GetColor(),
-                           self.shadow.GetProperty().GetOpacity())
+        if not locally:
+            T = vtk.vtkTransform()
+            self.ComputeMatrix()
+            T.SetMatrix(self.GetMatrix())
+            T.PostMultiply()
+            T.RotateX(angle)
+            self.SetOrientation(T.GetOrientation())
+            self.SetPosition(T.GetPosition())
+            if self.trail:
+                self.updateTrail()
+            if self.shadow:
+                self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
+                               self.shadow.GetProperty().GetColor(),
+                               self.shadow.GetProperty().GetOpacity())
+        else:
+            self.RotateX(angle)
         return self
 
-    def rotateY(self, angle, rad=False):
-        """Rotate around y-axis. If angle is in radians set ``rad=True``."""
+    def rotateY(self, angle, rad=False, locally=False):
+        """Rotate around y-axis. If angle is in radians set ``rad=True``.
+
+        :param bool locally: ignore previous transformations. Rotate around object local origin.
+        """
         if rad:
             angle *= 180 / np.pi
-        T = vtk.vtkTransform()
-        self.ComputeMatrix()
-        T.SetMatrix(self.GetMatrix())
-        T.PostMultiply()
-        T.RotateY(angle)
-        self.SetOrientation(T.GetOrientation())
-        self.SetPosition(T.GetPosition())
-        if self.trail:
-            self.updateTrail()
-        if self.shadow:
-            self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                           self.shadow.GetProperty().GetColor(),
-                           self.shadow.GetProperty().GetOpacity())
+        if not locally:
+            T = vtk.vtkTransform()
+            self.ComputeMatrix()
+            T.SetMatrix(self.GetMatrix())
+            T.PostMultiply()
+            T.RotateY(angle)
+            self.SetOrientation(T.GetOrientation())
+            self.SetPosition(T.GetPosition())
+            if self.trail:
+                self.updateTrail()
+            if self.shadow:
+                self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
+                               self.shadow.GetProperty().GetColor(),
+                               self.shadow.GetProperty().GetOpacity())
+        else:
+            self.RotateY(angle)
         return self
 
-    def rotateZ(self, angle, rad=False):
-        """Rotate around z-axis. If angle is in radians set ``rad=True``."""
+    def rotateZ(self, angle, rad=False, locally=False):
+        """Rotate around z-axis. If angle is in radians set ``rad=True``.
+
+        :param bool locally: ignore previous transformations. Rotate around object local origin.
+        """
         if rad:
             angle *= 180 / np.pi
-        T = vtk.vtkTransform()
-        self.ComputeMatrix()
-        T.SetMatrix(self.GetMatrix())
-        T.PostMultiply()
-        T.RotateZ(angle)
-        self.SetOrientation(T.GetOrientation())
-        self.SetPosition(T.GetPosition())
-        if self.trail:
-            self.updateTrail()
-        if self.shadow:
-            self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
-                           self.shadow.GetProperty().GetColor(),
-                           self.shadow.GetProperty().GetOpacity())
+        if not locally:
+            T = vtk.vtkTransform()
+            self.ComputeMatrix()
+            T.SetMatrix(self.GetMatrix())
+            T.PostMultiply()
+            T.RotateZ(angle)
+            self.SetOrientation(T.GetOrientation())
+            self.SetPosition(T.GetPosition())
+            if self.trail:
+                self.updateTrail()
+            if self.shadow:
+                self.addShadow(self.shadowX, self.shadowY, self.shadowZ,
+                               self.shadow.GetProperty().GetColor(),
+                               self.shadow.GetProperty().GetOpacity())
+        else:
+            self.RotateZ(angle)
         return self
 
 
@@ -527,7 +541,7 @@ class Base3DProp(object):
     def diagonalSize(self):
         """Get the length of the diagonal of mesh bounding box."""
         b = self.GetBounds()
-        return np.sqrt((b[1]-b[0])**2 + (b[3]-b[2])* 2 + (b[5]-b[4])**2)
+        return np.sqrt((b[1]-b[0])**2 + (b[3]-b[2])**2 + (b[5]-b[4])**2)
         # return self.GetLength() # ???different???
 
     def maxBoundSize(self):
@@ -579,13 +593,9 @@ class Base3DProp(object):
         Create on the fly an instance of class ``Plotter`` or use the last existing one to
         show one single object.
 
-        This is meant as a shortcut. If more than one object needs to be visualised
+        This method is meant as a shortcut. If more than one object needs to be visualised
         please use the syntax `show(mesh1, mesh2, volume, ..., options)`.
 
-        :param bool new: if set to `True`, a call to ``show`` will instantiate
-            a new ``Plotter`` object (a new window) instead of reusing the first created.
-            See e.g.: |readVolumeAsIsoSurface.py|_
-
         :return: the current ``Plotter`` class instance.
 
         .. note:: E.g.:
@@ -649,6 +659,49 @@ class BaseActor(Base3DProp):
         """Retrieve number of cells."""
         return self.inputdata().GetNumberOfCells()
 
+
+    def points(self, pts=None, transformed=True, copy=False):
+        """
+        Set/Get the vertex coordinates of a mesh or point cloud.
+        Argument can be an index, a set of indices
+        or a complete new set of points to update the mesh.
+
+        :param bool transformed: if `False` ignore any previous transformation
+            applied to the mesh.
+        :param bool copy: if `False` return the reference to the points
+            so that they can be modified in place, otherwise a copy is built.
+        """
+        if pts is None: ### getter
+
+            if isinstance(self, vedo.Points):
+                vpts = self.polydata(transformed).GetPoints()
+            else:
+                vpts = self._data.GetPoints()
+
+            if vpts:
+                if copy:
+                    return utils.vtk2numpy(vpts.GetData())
+                else:
+                    return utils.vtk2numpy(vpts.GetData())
+            else:
+                return np.array([])
+
+        elif (utils.isSequence(pts) and not utils.isSequence(pts[0])) or isinstance(pts, (int, np.integer)):
+            #passing a list of indices or a single index
+            return utils.vtk2numpy(self.polydata(transformed).GetPoints().GetData())[pts]
+
+        else:           ### setter
+
+            if len(pts) == 3 and len(pts[0]) != 3:
+                # assume plist is in the format [all_x, all_y, all_z]
+                pts = np.stack((pts[0], pts[1], pts[2]), axis=1)
+            vpts = self._data.GetPoints()
+            vpts.SetData(utils.numpy2vtk(pts, dtype=np.float))
+            vpts.Modified()
+            # reset mesh to identity matrix position/rotation:
+            self.PokeMatrix(vtk.vtkMatrix4x4())
+            return self
+
     def cellCenters(self):
         """Get the coordinates of the cell centers.
 
@@ -660,7 +713,7 @@ class BaseActor(Base3DProp):
         else:
             vcen.SetInputData(self.inputdata())
         vcen.Update()
-        return vtk_to_numpy(vcen.GetOutput().GetPoints().GetData())
+        return utils.vtk2numpy(vcen.GetOutput().GetPoints().GetData())
 
 
     def deleteCells(self, ids):
@@ -833,82 +886,37 @@ class BaseActor(Base3DProp):
 
 
     def getArrayNames(self):
+        """Get the existing arrays names as a dictionary"""
         from vtk.numpy_interface import dataset_adapter
         wrapped = dataset_adapter.WrapDataObject(self.GetMapper().GetInput())
         return {"PointData":wrapped.PointData.keys(),
                 "CellData":wrapped.CellData.keys() }
 
-
     def getPointArray(self, name=0):
-        """Return point array content as a ``numpy.array``.
-        This can be identified either as a string or by an integer number.
-
-        Getting an array also makes it the active one, if more than one is present.
         """
-        if hasattr(self, '_polydata') and self._polydata:
-            data = self._polydata.GetPointData()
-            if isinstance(name, int):
-                name = data.GetArrayName(name)
-            arr = data.GetArray(name)
-            if not arr:
-                return None
-
-            self._mapper.ScalarVisibilityOn()
-            if settings.autoResetScalarRange:
-                if self._mapper.GetLookupTable().GetTable().GetNumberOfTuples():
-                    self._mapper.SetScalarRange(self._mapper.GetLookupTable().GetRange())
-                else:
-                    self._mapper.SetScalarRange(arr.GetRange())
-
-        else:
-            indata = self.inputdata()
-            if indata:
-                data = indata.GetPointData()
-                if isinstance(name, int):
-                    name = data.GetArrayName(name)
-                arr = data.GetArray(name)
-                if not arr:
-                    return None
-
-        data.SetActiveScalars(name)
-        self._mapper.SetScalarModeToUsePointData()
-        return vtk_to_numpy(arr)
-
+        Return the point array content as a ``numpy.array``.
+        This can be identified either as a string or by an integer number.
+        """
+        data = self._data.GetPointData()
+        if isinstance(name, int):
+            name = data.GetArrayName(name)
+        arr = data.GetArray(name)
+        if not arr:
+            return None
+        return utils.vtk2numpy(arr)
 
     def getCellArray(self, name=0):
-        """Return cell array content as a ``numpy.array``.
-        This can be identified either as a string or by an integer number.
-
-        Getting an array also makes it the active one, if more than one is present.
         """
-        if hasattr(self, '_polydata') and self._polydata:
-            data = self._polydata.GetCellData()
-            if isinstance(name, int):
-                name = data.GetArrayName(name)
-            arr = data.GetArray(name)
-            if not arr:
-                return None
-
-            self._mapper.ScalarVisibilityOn()
-            if settings.autoResetScalarRange:
-                if self._mapper.GetLookupTable().GetTable().GetNumberOfTuples():
-                    self._mapper.SetScalarRange(self._mapper.GetLookupTable().GetRange())
-                else:
-                    self._mapper.SetScalarRange(arr.GetRange())
-
-        else:
-            indata = self.inputdata()
-            if indata:
-                data = indata.GetCellData()
-                if isinstance(name, int):
-                    name = data.GetArrayName(name)
-                arr = data.GetArray(name)
-                if not arr:
-                    return None
-
-        data.SetActiveScalars(name)
-        self._mapper.SetScalarModeToUseCellData()
-        return vtk_to_numpy(arr)
+        Return the cell array content as a ``numpy.array``.
+        This can be identified either as a string or by an integer number.
+        """
+        data = self._data.GetCellData()
+        if isinstance(name, int):
+            name = data.GetArrayName(name)
+        arr = data.GetArray(name)
+        if not arr:
+            return None
+        return utils.vtk2numpy(arr)
 
 
     def addIDs(self, asfield=False):
@@ -918,7 +926,7 @@ class BaseActor(Base3DProp):
         :param bool asfield: flag to control whether to generate scalar or field data.
         """
         ids = vtk.vtkIdFilter()
-        ids.SetInputData(self._polydata)
+        ids.SetInputData(self._data)
         ids.PointIdsOn()
         ids.CellIdsOn()
         if asfield:
@@ -931,32 +939,36 @@ class BaseActor(Base3DProp):
     def selectPointArray(self, name):
         """Make this point array the active one. Name can be a string or integer."""
         data = self.inputdata().GetPointData()
+        arrname = name
         if isinstance(name, int):
-            name = data.GetArray(name)
-        data.SetActiveScalars(name)
+            arrname = data.GetArrayName(name)
+        data.SetActiveScalars(arrname)
         if hasattr(self._mapper, 'SetArrayName'):
-            self._mapper.SetArrayName(name)
+            self._mapper.SetArrayName(arrname)
         self._mapper.SetScalarModeToUsePointData()
         return self
 
     def selectCellArray(self, name):
         """Make this cell array the active one. Name can be a string or integer."""
         data = self.inputdata().GetCellData()
+        arrname = name
         if isinstance(name, int):
-            name = data.GetArray(name)
-        data.SetActiveScalars(name)
+            arrname = data.GetArrayName(name)
+        data.SetActiveScalars(arrname)
         if hasattr(self._mapper, 'SetArrayName'):
-            self._mapper.SetArrayName(name)
+            self._mapper.SetArrayName(arrname)
         self._mapper.SetScalarModeToUseCellData()
         return self
 
     def removePointArray(self, name):
         """Reomve point array from object."""
         self.inputdata().GetPointData().RemoveArray(name)
+        return self
 
     def removeCellArray(self, name):
         """Reomve cell array from object."""
         self.inputdata().GetCellData().RemoveArray(name)
+        return self
 
     def addPointArray(self, input_array, name):
         """
@@ -984,7 +996,7 @@ class BaseActor(Base3DProp):
 
         nparr = np.ascontiguousarray(input_array)
         if len(nparr.shape)==1: # scalars
-            varr = numpy_to_vtk(nparr, deep=True)
+            varr = utils.numpy2vtk(nparr)
             varr.SetName(name)
             data.GetPointData().AddArray(varr)
             data.GetPointData().SetActiveScalars(name)
@@ -1043,7 +1055,7 @@ class BaseActor(Base3DProp):
 
         nparr = np.ascontiguousarray(input_array)
         if len(nparr.shape)==1: # scalars
-            varr = numpy_to_vtk(nparr, deep=True)
+            varr = utils.numpy2vtk(nparr)
             varr.SetName(name)
             data.GetCellData().AddArray(varr)
             data.GetCellData().SetActiveScalars(name)
@@ -1108,9 +1120,9 @@ class BaseActor(Base3DProp):
         gra.ComputeGradientOn()
         gra.Update()
         if on.startswith('p'):
-            gvecs = vtk_to_numpy(gra.GetOutput().GetPointData().GetArray('Gradient'))
+            gvecs = utils.vtk2numpy(gra.GetOutput().GetPointData().GetArray('Gradient'))
         else:
-            gvecs = vtk_to_numpy(gra.GetOutput().GetCellData().GetArray('Gradient'))
+            gvecs = utils.vtk2numpy(gra.GetOutput().GetCellData().GetArray('Gradient'))
         return gvecs
 
     def divergence(self, arrname=None, on='points', fast=False):
@@ -1144,9 +1156,9 @@ class BaseActor(Base3DProp):
         div.SetFasterApproximation(fast)
         div.Update()
         if on.startswith('p'):
-            dvecs = vtk_to_numpy(div.GetOutput().GetPointData().GetArray('Divergence'))
+            dvecs = utils.vtk2numpy(div.GetOutput().GetPointData().GetArray('Divergence'))
         else:
-            dvecs = vtk_to_numpy(div.GetOutput().GetCellData().GetArray('Divergence'))
+            dvecs = utils.vtk2numpy(div.GetOutput().GetCellData().GetArray('Divergence'))
         return dvecs
 
     def vorticity(self, arrname=None, on='points', fast=False):
@@ -1180,9 +1192,9 @@ class BaseActor(Base3DProp):
         vort.SetFasterApproximation(fast)
         vort.Update()
         if on.startswith('p'):
-            vvecs = vtk_to_numpy(vort.GetOutput().GetPointData().GetArray('Vorticity'))
+            vvecs = utils.vtk2numpy(vort.GetOutput().GetPointData().GetArray('Vorticity'))
         else:
-            vvecs = vtk_to_numpy(vort.GetOutput().GetCellData().GetArray('Vorticity'))
+            vvecs = utils.vtk2numpy(vort.GetOutput().GetCellData().GetArray('Vorticity'))
         return vvecs
 
 
@@ -1257,7 +1269,9 @@ class BaseActor(Base3DProp):
                         titleRotation = 0.0,
                         nlabels=9,
                         labelFont="",
+                        labelSize=1,
                         labelOffset = 0.375,
+                        labelRotation=0,
                         italic=0,
                         c=None,
                         useAlpha=True,
@@ -1265,6 +1279,7 @@ class BaseActor(Base3DProp):
                         aboveText=None,
                         belowText=None,
                         nanText='NaN',
+                        categories=None,
         ):
         """
         Draw a 3D scalar bar.
@@ -1285,7 +1300,10 @@ class BaseActor(Base3DProp):
         :param float titleSize: size of title wrt numeric labels
         :param float titleRotation: title rotation in degrees
         :param int nlabels: number of numeric labels
+        :param str labelFont: font type for labels
+        :param float labelSize: label scale factor
         :param float labelOffset: space btw numeric labels and scale
+        :param float labelRotation: label rotation in degrees
         :param bool,float italic: use italic font for title and labels
         :param bool useAlpha: render transparency of the color bar, otherwise ignore
         :param bool drawBox: draw a box around the colorbar (useful with useAlpha=True)
@@ -1307,7 +1325,9 @@ class BaseActor(Base3DProp):
                                                     titleRotation,
                                                     nlabels,
                                                     labelFont,
+                                                    labelSize,
                                                     labelOffset,
+                                                    labelRotation,
                                                     italic,
                                                     c,
                                                     useAlpha,
@@ -1315,6 +1335,7 @@ class BaseActor(Base3DProp):
                                                     aboveText,
                                                     belowText,
                                                     nanText,
+                                                    categories,
                                                     )
         return self
 
@@ -1378,51 +1399,12 @@ class BaseGrid(BaseActor):
         # msh.selectCellArray('chem_0')
         return msh
 
-    def points(self, pts=None, transformed=True, copy=False):
-        """
-        Set/Get the vertex coordinates of the mesh.
-        Argument can be an index, a set of indices
-        or a complete new set of points to update the mesh.
-
-        :param bool transformed: if `False` ignore any previous transformation
-            applied to the mesh.
-        :param bool copy: if `False` return the reference to the points
-            so that they can be modified in place, otherwise a copy is built.
-        """
-        if pts is None: ### getter
-
-            vpts = self._data.GetPoints()
-            if vpts:
-                if copy:
-                    return np.array(vtk_to_numpy(vpts.GetData()))
-                else:
-                    return vtk_to_numpy(vpts.GetData())
-            else:
-                return np.array([])
-
-        elif (utils.isSequence(pts) and not utils.isSequence(pts[0])) or isinstance(pts, (int, np.integer)):
-            #passing a list of indices or a single index
-            return vtk_to_numpy(self.polydata(transformed).GetPoints().GetData())[pts]
-
-        else:           ### setter
-
-            if len(pts) == 3 and len(pts[0]) != 3:
-                # assume plist is in the format [all_x, all_y, all_z]
-                pts = np.stack((pts[0], pts[1], pts[2]), axis=1)
-            vpts = self._data.GetPoints()
-            vpts.SetData(numpy_to_vtk(np.ascontiguousarray(pts), deep=True))
-            self._data.GetPoints().Modified()
-            # reset mesh to identity matrix position/rotation:
-            self.PokeMatrix(vtk.vtkMatrix4x4())
-            return self
-
-
     def cells(self):
         """
         Get the cells connectivity ids as a numpy array.
         The output format is: [[id0 ... idn], [id0 ... idm],  etc].
         """
-        arr1d = vtk_to_numpy(self._data.GetCells().GetData())
+        arr1d = utils.vtk2numpy(self._data.GetCells().GetData())
         if arr1d is None:
             return []
 
@@ -1637,7 +1619,7 @@ class BaseGrid(BaseActor):
         gf.SetInputData(extract.GetOutput())
         gf.Update()
 
-        a = vedo.mesh.Mesh(gf.GetOutput()).lw(0.1).flat().lighting('plastic')
+        a = vedo.mesh.Mesh(gf.GetOutput()).lw(0.1).flat().lighting('ambient')
         scalars = a.getPointArray()
         if scalars is None:
             print("Error in legosurface(): no scalars found!")
@@ -1780,7 +1762,7 @@ class BaseGrid(BaseActor):
         else:
             selectionNode.SetFieldType(vtk.vtkSelectionNode.CELL)
         selectionNode.SetContentType(vtk.vtkSelectionNode.INDICES)
-        vidlist = numpy_to_vtkIdTypeArray(np.array(idlist).astype(np.int64))
+        vidlist = utils.numpy2vtk(idlist, dtype='id')
         selectionNode.SetSelectionList(vidlist)
         selection = vtk.vtkSelection()
         selection.AddNode(selectionNode)
