@@ -22,6 +22,8 @@ def tips():
     msg += "|        09+-  (on keypad) or +/- to cycle axes style      |\n"
     msg += "|        k     cycle available lighting styles             |\n"
     msg += "|        K     cycle available shading styles              |\n"
+    msg += "|        A     toggle anti-aliasing                        |\n"
+    msg += "|        D     toggle depth-peeling (for transparencies)   |\n"
     msg += "|        o/O   add/remove light to scene and rotate it     |\n"
     msg += "|        n     show surface mesh normals                   |\n"
     msg += "|        a     toggle interaction to Actor Mode            |\n"
@@ -44,11 +46,7 @@ def tips():
 
     msg = " vedo " + __version__ + " "
     colors.printc(msg, invert=1, dim=1, end="")
-    # try:
     vtkVers = vtk.vtkVersion().GetVTKVersion()
-    # vtkVers = vtk.VTK_VERSION_NUMBER
-    # except AttributeError:
-    #     vtkVers = 'unkonwn'
     msg = "| vtk " + str(vtkVers)
     msg += " | python " + str(sys.version_info[0]) + "." + str(sys.version_info[1])
     colors.printc(msg, invert=0, dim=1)
