@@ -1,5 +1,4 @@
 import vtk
-from vtk.util.numpy_support import vtk_to_numpy
 import os
 import glob
 import numpy as np
@@ -140,15 +139,15 @@ def load(inputobj, unpack=True, force=False):
             colors.printc("\times Error in load(): cannot find", fod, c='r')
 
     if len(acts) == 1:
+        if "numpy" in str(type(acts[0])):
+            return acts[0]
         if not acts[0]:
             colors.printc("\times Error in load(): cannot load", inputobj, c='r')
-        # settings.collectable_actors.append(acts[0])
         return acts[0]
     elif len(acts) == 0:
         colors.printc("\times Error in load(): cannot load", inputobj, c='r')
         return None
     else:
-        # settings.collectable_actors += acts
         return acts
 
 
@@ -329,6 +328,9 @@ def download(url, force=False, verbose=True):
         return url
     url = url.replace('www.dropbox', 'dl.dropbox')
 
+    if "github.com" in url:
+        url = url.replace('/blob/', '/raw/')
+
     basename = os.path.basename(url)
 
     if '?' in basename:
@@ -346,17 +348,21 @@ def download(url, force=False, verbose=True):
         return tmp_file.name
 
     try:
-        from urllib.request import urlopen
+        from urllib.request import urlopen, Request
+        req = Request(url, headers={'User-Agent': 'Mozilla/5.0'})
+        if verbose:
+            colors.printc('reading', basename, 'from',
+                          url.split('/')[2][:40],'...', end='')
     except ImportError:
         import urllib2
         import contextlib
         urlopen = lambda url_: contextlib.closing(urllib2.urlopen(url_))
+        req = url
+        if verbose:
+            colors.printc('reading', basename, 'from',
+                          url.split('/')[2][:40],'...', end='')
 
-    if verbose:
-        colors.printc('reading', basename, 'from',
-                      url.split('/')[2][:40],'...', end='')
-
-    with urlopen(url) as response, open(tmp_file.name, 'wb') as output:
+    with urlopen(req) as response, open(tmp_file.name, 'wb') as output:
         output.write(response.read())
 
     if verbose: colors.printc(' done.')
@@ -701,7 +707,7 @@ def loadGmesh(filename):
 
 def loadPCD(filename):
     """Return a ``Mesh`` made of only vertex points
-    from `Point Cloud` file format. Return an ``Mesh`` object."""
+    from `Point Cloud` file format. Return an ``Points`` object."""
     f = open(filename, "r")
     lines = f.readlines()
     f.close()
@@ -722,7 +728,7 @@ def loadPCD(filename):
     if expN != N:
         colors.printc("Mismatch in pcd file", expN, len(pts), c="red")
     poly = utils.buildPolyData(pts)
-    return Mesh(poly).pointSize(4)
+    return Points(poly).pointSize(4)
 
 
 def toNumpy(obj):
@@ -774,12 +780,12 @@ def toNumpy(obj):
         for iname in obj.getArrayNames()['PointData']:
             if 'Normals' in iname.lower(): continue
             arr = poly.GetPointData().GetArray(iname)
-            adict['pointdata'].append([vtk_to_numpy(arr), iname])
+            adict['pointdata'].append([utils.vtk2numpy(arr), iname])
         adict['celldata'] = []
         for iname in obj.getArrayNames()['CellData']:
             if 'Normals' in iname.lower(): continue
             arr = poly.GetCellData().GetArray(iname)
-            adict['celldata'].append([vtk_to_numpy(arr), iname])
+            adict['celldata'].append([utils.vtk2numpy(arr), iname])
 
         adict['activedata'] = None
         if poly.GetPointData().GetScalars():
@@ -849,7 +855,7 @@ def toNumpy(obj):
         adict['type'] = 'Volume'
         _fillcommon(obj, adict)
         imgdata = obj.inputdata()
-        arr = vtk_to_numpy(imgdata.GetPointData().GetScalars())
+        arr = utils.vtk2numpy(imgdata.GetPointData().GetScalars())
         adict['array'] = arr.reshape(imgdata.GetDimensions())
         adict['mode'] = obj.mode()
         #adict['jittering'] = obj.mapper().GetUseJittering()
@@ -874,7 +880,7 @@ def toNumpy(obj):
     elif isinstance(obj, Picture):
         adict['type'] = 'Picture'
         _fillcommon(obj, adict)
-        adict['array'] = vtk_to_numpy(obj.inputdata().GetPointData().GetScalars())
+        adict['array'] = utils.vtk2numpy(obj.inputdata().GetPointData().GetScalars())
         adict['shape'] = obj.inputdata().GetDimensions()
         print('toNumpy(): vedo.Picture', obj.shape, obj.GetPosition())
 
@@ -906,16 +912,20 @@ def loadNumpy(inobj):
     if isinstance(inobj, str): # user passing a file
 
         if inobj.endswith('.npy'):
-            data = np.load(inobj, allow_pickle=True, encoding='latin1').flatten()
+            data = np.load(inobj, allow_pickle=True, encoding='latin1')#.flatten()
         elif  inobj.endswith('.npz'):
             data = np.load(inobj, allow_pickle=True)['vedo_scenes']
-            #print(data.files)
 
-        if "objects" in data[0].keys():  # loading a full scene!!
-            return importWindow(data[0]) # <-------
+        isdict = hasattr(data[0], "keys")
 
+        if isdict and "objects" in data[0].keys():  # loading a full scene!!
+            return importWindow(data[0])
+
+        # it's a very normal numpy data object? just return it!
+        if not isdict:
+            return data
         if 'type' not in data[0].keys():
-            return data[0] # it's a very normal numpy data object, just return it!
+            return data
 
     else:
         data = inobj
@@ -1104,6 +1114,8 @@ def loadImageData(filename):
     """
     if ".tif" in filename.lower():
         reader = vtk.vtkTIFFReader()
+        # print("GetOrientationType ", reader.GetOrientationType())
+        reader.SetOrientationType(settings.tiffOrientationType)
     elif ".slc" in filename.lower():
         reader = vtk.vtkSLCReader()
         if not reader.CanReadFile(filename):
@@ -1190,6 +1202,7 @@ def write(objct, fileoutput, binary=True):
         writer = vtk.vtkFacetWriter()
     elif fr.endswith(".tif"):
         writer = vtk.vtkTIFFWriter()
+        # print("GetCompression ", writer.GetCompression ())
         writer.SetFileDimensionality(len(obj.GetDimensions()))
     elif fr.endswith(".vti"):
         writer = vtk.vtkXMLImageDataWriter()
@@ -1659,7 +1672,7 @@ def screenshot(filename="screenshot.png", scale=None, returnNumpy=False):
 
     if returnNumpy:
         w2ifout = w2if.GetOutput()
-        npdata = vtk_to_numpy(w2ifout.GetPointData().GetArray("ImageScalars"))
+        npdata = utils.vtk2numpy(w2ifout.GetPointData().GetArray("ImageScalars"))
         npdata = npdata[:,[0,1,2]]
         ydim, xdim, _ = w2ifout.GetDimensions()
         npdata = npdata.reshape([xdim, ydim, -1])
