@@ -38,32 +38,32 @@ General settings.
         -10 = Terrain
         -11 = Unicam
 
-    # Allow to interact with scene during interactor.Start() execution
+    # Allow to continously interact with scene during interactive() execution
     allowInteraction = True
 
+    # Set up default mouse and keyboard functionalities
+    enableDefaultMouseCallbacks = True
+    enableDefaultKeyboardCallbacks = True
+
     # If False, when multiple renderers are present do not render each one for separate
     #  but do it just once at the end (when interactive() is called)
     immediateRendering = True
 
     # Show a gray frame margin in multirendering windows
-    showRendererFrame = True
     rendererFrameColor = None
+    rendererFrameAlpha = 0.5
+    rendererFrameWidth = 0.5
+    rendererFramePadding = 0.0001
 
     # In multirendering mode set the position of the horizontal of vertical splitting [0,1]
     windowSplittingPosition = None
 
-    # Use tex, matplotlib latex compiler
-    usetex = False
-
     # Enable / disable color printing by printc()
     enablePrintColor = True
 
     # Qt embedding
     usingQt = False
 
-    # OpenVR rendering (untested)
-    useOpenVR = False
-
     # Wrap lines in tubes
     renderLinesAsTubes = False
 
@@ -89,8 +89,18 @@ General settings.
     maxNumberOfPeels= 8     # maximum number of rendering passes
     occlusionRatio  = 0.0   # occlusion ratio, 0 = exact image.
 
-    # Turn on/off nvidia FXAA anti-aliasing, if supported.
-    useFXAA = None          # either True or False. None sets the system default
+    # Turn on/off nvidia FXAA post-process anti-aliasing, if supported.
+    useFXAA = False         # either True or False
+
+    # By default, the depth buffer is reset for each renderer. If True, use the existing depth buffer
+    preserveDepthBuffer = False
+
+    # Turn on/off Screen Space Ambient Occlusion (SSAO), darken some pixels to improve depth perception
+    useSSAO         = False
+    SSAORadius      = 0.5   # the SSAO hemisphere radius
+    SSAOBias        = 0.01  # the bias when comparing samples
+    SSAOKernelSize  = 32    # the number of samples
+    SSAOBlur        = False # blurring of the ambient occlusion (helps for low samples nr)
 
     # Use a polygon/edges offset to possibly resolve conflicts in rendering
     usePolygonOffset    = False
@@ -103,16 +113,18 @@ General settings.
     # Set parallel projection On or Off (place camera to infinity, no perspective effects)
     useParallelProjection = False
 
+    # Set orientation type when reading TIFF files (volumes):
+    # TOPLEFT  1 (row 0 top, col 0 lhs)    TOPRIGHT 2 (row 0 top, col 0 rhs)
+    # BOTRIGHT 3 (row 0 bottom, col 0 rhs) BOTLEFT  4 (row 0 bottom, col 0 lhs)
+    # LEFTTOP  5 (row 0 lhs, col 0 top)    RIGHTTOP 6 (row 0 rhs, col 0 top)
+    # RIGHTBOT 7 (row 0 rhs, col 0 bottom) LEFTBOT  8 (row 0 lhs, col 0 bottom)
+    tiffOrientationType = 4
+
     # AnnotatedCube axis type nr. 5 options:
     annotatedCubeColor      = (0.75, 0.75, 0.75)
     annotatedCubeTextColor  = None # use default, otherwise specify a single color
     annotatedCubeTextScale  = 0.2
-    annotatedCubeXPlusText  = "right"
-    annotatedCubeXMinusText = "left "
-    annotatedCubeYPlusText  = "front"
-    annotatedCubeYMinusText = "back "
-    annotatedCubeZPlusText  = " top "
-    annotatedCubeZMinusText = "bttom"
+    annotatedCubeTexts      = ["right","left ", "front","back ", " top ", "bttom"]
 
 Usage example:
 
@@ -123,13 +135,23 @@ Usage example:
     settings.useParallelProjection = True
 
     Cube().color('green').show()
-
 """
 import os, vtk
 
 __all__ = ['datadir', 'dataurl', 'embedWindow']
 
 
+vtk_version = [ int(vtk.vtkVersion().GetVTKMajorVersion()),
+                int(vtk.vtkVersion().GetVTKMinorVersion()),
+                int(vtk.vtkVersion().GetVTKBuildVersion()) ]
+
+try:
+    import platform
+    sys_platform = platform.system()
+except:
+    sys_platform = ""
+
+
 ####################################################################################
 # Axes titles
 xtitle = 'x'
@@ -154,28 +176,26 @@ autoResetScalarRange = True
 # Default style is TrackBallCamera
 interactorStyle = None
 
-# Allow to interact with scene during interactor.Start() execution
+# Allow to continously interact with scene during interactor.Start() execution
 allowInteraction = True
 
+# Set up default mouse and keyboard functionalities
+enableDefaultMouseCallbacks = True
+enableDefaultKeyboardCallbacks = True
+
 # When multiple renderers are present do not render each one for separate.
 # but do it just once at the end (when interactive() is called)
 immediateRendering = True
 
 # Show a gray frame margin in multirendering windows
-showRendererFrame = True
 rendererFrameColor = None
 rendererFrameAlpha = 0.5
 rendererFrameWidth = 0.5
-
-# Use tex, matplotlib latex compiler
-usetex = False
+rendererFramePadding = 0.0001
 
 # Qt embedding
 usingQt = False
 
-# OpenVR rendering
-useOpenVR = False
-
 # Wrap lines in tubes
 renderLinesAsTubes = False
 
@@ -195,17 +215,29 @@ lightFollowsCamera = False
 twoSidedLighting = True
 
 # Turn on/off rendering of translucent material with depth peeling technique.
-#https://lorensen.github.io/VTKExamples/site/Cxx/Visualization/CorrectlyRenderTranslucentGeometry
+#print("vtk_version sys_platform", vtk_version, sys_platform)
 useDepthPeeling = False
-if '9' in vtk.vtkVersion().GetVTKVersion():
-    useDepthPeeling = True
-alphaBitPlanes  = True  # only relevant if useDepthPeeling
-multiSamples    = 0
-maxNumberOfPeels= 8
-occlusionRatio  = 0.0
+multiSamples = 8
+if vtk_version[0] >= 9:
+    if "Windows" in sys_platform:
+        useDepthPeeling = True
+# only relevant if depthpeeling is on
+alphaBitPlanes = 1
+maxNumberOfPeels= 4
+occlusionRatio  = 0.1
 
 # Turn on/off nvidia FXAA anti-aliasing, if supported.
-useFXAA = None           # either True or False. None sets the system default
+useFXAA = False  # either True or False
+
+# By default, the depth buffer is reset for each renderer. If true, use the existing depth buffer
+preserveDepthBuffer = False
+
+#Enable or disable Screen Space Ambient Occlusion: SSAO darkens some pixels to improve depth perception.
+useSSAO        = False
+SSAORadius     = 0.5     # define the SSAO hemisphere radius
+SSAOBias       = 0.01    # define the bias when comparing samples
+SSAOKernelSize = 32      # define the number of samples
+SSAOBlur       = False   # define blurring of the ambient occlusion (helps for low samples)
 
 # Use a polygon/edges offset to possibly resolve conflicts in rendering
 usePolygonOffset = False
@@ -221,16 +253,18 @@ useParallelProjection = False
 # In multirendering mode set the position of the horizontal of vertical splitting [0,1]
 windowSplittingPosition = None
 
+# Set orientation type when reading TIFF files (volumes):
+# TOPLEFT  1 (row 0 top, col 0 lhs)    TOPRIGHT 2 (row 0 top, col 0 rhs)
+# BOTRIGHT 3 (row 0 bottom, col 0 rhs) BOTLEFT  4 (row 0 bottom, col 0 lhs)
+# LEFTTOP  5 (row 0 lhs, col 0 top)    RIGHTTOP 6 (row 0 rhs, col 0 top)
+# RIGHTBOT 7 (row 0 rhs, col 0 bottom) LEFTBOT  8 (row 0 lhs, col 0 bottom)
+tiffOrientationType = 1
+
 # AnnotatedCube axis (type 5) customization:
 annotatedCubeColor      = (0.75, 0.75, 0.75)
 annotatedCubeTextColor  = None # use default, otherwise specify a single color
 annotatedCubeTextScale  = 0.2
-annotatedCubeXPlusText  = "right"
-annotatedCubeXMinusText = "left "
-annotatedCubeYPlusText  = "front"
-annotatedCubeYMinusText = "back "
-annotatedCubeZPlusText  = " top "
-annotatedCubeZMinusText = "bttom"
+annotatedCubeTexts      = ["right","left ", "front","back ", " top ", "bttom"]
 
 # enable / disable color printing
 enablePrintColor = True
@@ -253,7 +287,8 @@ flagColor = 'k'
 flagBackgroundColor = 'w'
 
 
-#############################
+#######################################################################################
+#######################################################################################
 installdir = os.path.dirname(__file__)
 
 textures_path = os.path.join(installdir, "textures/")
@@ -264,11 +299,12 @@ fonts = []
 
 #dataurl = "/home/musy/Dropbox/Public/vktwork/vedo_data/"; print('\ndataurl=',dataurl)
 dataurl = "https://vedo.embl.es/examples/data/"
-datadir = dataurl
+datadir = dataurl # will disappear
 
 plotter_instances = []
 plotter_instance = None
 
+####################################################################################
 ####################################################################################
 # mono       # means that all letters occupy the same space slot horizontally
 # hspacing   # an horizontal stretching factor (affects both letters and words)
@@ -445,14 +481,6 @@ font_parameters = dict(
                         dotsep = "·",
                         islocal = False,
                         ),
-        VTK = dict(
-                        mono = False,
-                        fscale = 0.8,
-                        hspacing = 0.6,
-                        lspacing = 0.4,
-                        dotsep = "~^.~ ",
-                        islocal = True,
-                        ),
         Meson= dict(
                         mono = False,
                         fscale = 0.8,
@@ -461,11 +489,19 @@ font_parameters = dict(
                         dotsep = "~^.~ ",
                         islocal = False,
                         ),
+        Komika= dict(
+                        mono = False,
+                        fscale = 0.7,
+                        hspacing = 0.75,
+                        lspacing = 0.225,
+                        dotsep = "~^.~ ",
+                        islocal = False,
+                        ),
 )
 
 
 ####################################################################################
-def embedWindow(backend='k3d', verbose=True):
+def embedWindow(backend='ipyvtk', verbose=True):
     """Use this function to control whether the rendering window is inside
     the jupyter notebook or as an independent external window"""
     global notebook_plotter, notebookBackend
@@ -526,7 +562,7 @@ def embedWindow(backend='k3d', verbose=True):
 
     elif 'ipyvtk' in backend:
         try:
-            from ipyvtk_simple.viewer import ViewInteractiveWidget
+            from ipyvtklink.viewer import ViewInteractiveWidget
         except:
             if verbose:
                 print('embedWindow(verbose=True): could not load ipyvtk_simple try:')
