@@ -1,11 +1,11 @@
-from __future__ import division, print_function
-import vtk, sys
-from vtk.util.numpy_support import numpy_to_vtk, numpy_to_vtkIdTypeArray
+import vtk
+from vtk.util.numpy_support import numpy_to_vtk, vtk_to_numpy, numpy_to_vtkIdTypeArray
 import numpy as np
 import vedo
 from vedo.colors import printc
 import time
 import math
+import sys
 
 __doc__ = (
     """
@@ -24,6 +24,7 @@ __all__ = [
     "mag2",
     "versor",
     "precision",
+    "roundToDigit",
     "pointIsInTriangle",
     "pointToLineDistance",
     "grep",
@@ -43,6 +44,8 @@ __all__ = [
     "vedo2trimesh",
     "trimesh2vedo",
     "resampleArrays",
+    "vtk2numpy",
+    "numpy2vtk",
 ]
 
 ###########################################################################
@@ -248,6 +251,33 @@ class dotdict(dict):
 
 
 ###########################################################
+def numpy2vtk(arr, dtype=None, deep=True, name=""):
+    """Convert a numpy array into a vtkDataArray"""
+    if arr is None:
+        return None
+    arr = np.ascontiguousarray(arr)
+    if dtype is not None and dtype!='id':
+        arr = arr.astype(dtype)
+
+    if dtype and dtype=='id':
+        varr = numpy_to_vtkIdTypeArray(arr.astype(np.int64), deep=deep)
+    else:
+        varr = numpy_to_vtk(arr, deep=deep)
+    if name:
+        varr.SetName(name)
+    return varr
+
+def vtk2numpy(varr):
+    """Convert a vtkDataArray or vtkIdList into a numpy array"""
+    if isinstance(varr, vtk.vtkIdList):
+        return np.array([varr.GetId(i) for i in range(varr.GetNumberOfIds())])
+    elif isinstance(varr, vtk.vtkBitArray):
+        carr = vtk.vtkCharArray()
+        carr.DeepCopy(varr)
+        varr = carr
+    return vtk_to_numpy(varr)
+
+
 def geometry(obj, extent=None):
     """
     Apply the ``vtkGeometryFilter``.
@@ -303,7 +333,8 @@ def buildPolyData(vertices, faces=None, lines=None, indexOffset=0, fast=True, te
             vertices = np.c_[vertices, np.zeros(len(vertices))]
 
     sourcePoints = vtk.vtkPoints()
-    sourcePoints.SetData(numpy_to_vtk(np.ascontiguousarray(vertices), deep=True))
+    # sourcePoints.SetData(numpy_to_vtk(np.ascontiguousarray(vertices), deep=True))
+    sourcePoints.SetData(numpy2vtk(vertices, dtype=np.float))
     poly.SetPoints(sourcePoints)
 
     if lines is not None:
@@ -468,26 +499,10 @@ def humansort(l):
 
 
 def sortByColumn(array, nth):
-    '''Sort a numpy array by the `n-th` column'''
+    '''Sort a numpy array by its `n-th` column'''
     return array[array[:,nth].argsort()]
 
 
-def findDistanceToLines2D(P0,P1, pts):
-    """
-    Consider 2 sets of points P0,P1 describing lines (2D) and a set of points pts,
-    compute distance from each point j (P[j]) to each line i (P0[i],P1[i]).
-    """
-    #Author: Italmassov Kuanysh, at https://github.com/rougier/numpy-100
-    def _distance(P0, P1, p):
-        T = P1 - P0
-        L = (T**2).sum(axis=1)
-        U = -((P0[:,0]-p[...,0])*T[:,0] + (P0[:,1]-p[...,1])*T[:,1]) / L
-        U = U.reshape(len(U),1)
-        D = P0 + U*T - p
-        return np.sqrt((D**2).sum(axis=1))
-    return [_distance(P0,P1,p_i) for p_i in pts]
-
-
 def pointIsInTriangle(p, p1, p2, p3):
     """
     Return True if a point is inside (or above/below) a triangle defined by 3 points in space.
@@ -509,6 +524,58 @@ def pointIsInTriangle(p, p1, p2, p3):
                 return True
     return False
 
+def intersectRayTriangle(P0,P1, V0,V1,V2):
+    """
+    Fast intersection between a directional ray defined by P0,P1
+    and triangle V0, V1, V2.
+
+    Returns the intersection point or
+    ``None`` if triangle is degenerate, or ray is  parallel to triangle plane.
+    ``False`` if no intersection, or ray direction points away from triangle.
+    """
+    # Credits: http://geomalgorithms.com/a06-_intersect-2.html
+    # Get triangle edge vectors and plane normal
+    V0 = np.asarray(V0, dtype=float)
+    P0 = np.asarray(P0, dtype=float)
+    u = V1 - V0
+    v = V2 - V0
+    n = np.cross(u, v)
+    if not np.abs(v).sum():   # triangle is degenerate
+        return None           # do not deal with this case
+
+    rd = P1 - P0              # ray direction vector
+    w0 = P0 - V0
+    a = -np.dot(n, w0)
+    b =  np.dot(n, rd)
+    if not b:                 # ray is  parallel to triangle plane
+        return None
+
+    # Get intersect point of ray with triangle plane
+    r = a / b
+    if r < 0.0:               # ray goes away from triangle
+        return False          #  => no intersect
+
+    # Gor a segment, also test if (r > 1.0) => no intersect
+    I = P0 + r * rd           # intersect point of ray and plane
+
+    # is I inside T?
+    uu = np.dot(u,u)
+    uv = np.dot(u,v)
+    vv = np.dot(v,v)
+    w = I - V0
+    wu = np.dot(w,u)
+    wv = np.dot(w,v)
+    D = uv * uv - uu * vv
+
+    # Get and test parametric coords
+    s = (uv * wv - vv * wu) / D
+    if s < 0.0 or s > 1.0:       # I is outside T
+        return False
+    t = (uv * wu - uu * wv) / D
+    if t < 0.0 or (s + t) > 1.0: # I is outside T
+        return False
+    return I                     # I is in T
+
 
 def pointToLineDistance(p, p1, p2):
     """Compute the distance of a point to a line (not the segment) defined by `p1` and `p2`."""
@@ -518,7 +585,7 @@ def pointToLineDistance(p, p1, p2):
 
 def linInterpolate(x, rangeX, rangeY):
     """
-    Interpolate linearly variable x in rangeX onto rangeY.
+    Interpolate linearly the variable x in rangeX onto the new rangeY.
     If x is a 3D vector the linear weight is the distance to the two 3D rangeX vectors.
 
     E.g. if x runs in rangeX=[x0,x1] and I want it to run in rangeY=[y0,y1] then
@@ -560,7 +627,7 @@ def linInterpolate(x, rangeX, rangeY):
 def vector(x, y=None, z=0.0, dtype=np.float64):
     """Return a 3D numpy array representing a vector.
 
-    If `y` is ``None``, assume input is in the form `[x,y,z]`.
+    If `y` is ``None``, assume input is already in the form `[x,y,z]`.
     """
     if y is None:  # assume x is already [x,y,z]
         return np.asarray(x, dtype=dtype)
@@ -569,40 +636,50 @@ def vector(x, y=None, z=0.0, dtype=np.float64):
 
 def versor(x, y=None, z=0.0, dtype=np.float64):
     """Return the unit vector. Input can be a list of vectors."""
-    v = vector(x,y,z,dtype)
+    v = vector(x,y,z, dtype)
     if isinstance(v[0], np.ndarray):
         return np.divide(v, mag(v)[:, None])
     else:
         return v / mag(v)
 
 
-def mag(z):
-    """Get the magnitude of a vector."""
-    if isinstance(z[0], np.ndarray):
-        return np.array(list(map(np.linalg.norm, z)))
+def mag(v):
+    """Get the magnitude of a vector or array of vectors."""
+    v = np.asarray(v)
+    if v.ndim == 1:
+        return np.linalg.norm(v)
     else:
-        return np.linalg.norm(z)
+        return np.linalg.norm(v, axis=1)
+
+def mag2(v):
+    """Get the squared magnitude of a vector or array of vectors."""
+    v = np.asarray(v)
+    if v.ndim == 1:
+        return np.square(v).sum()
+    else:
+        return np.square(v).sum(axis=1)
 
 
-def mag2(z):
-    """Get the squared magnitude of a vector."""
-    return np.dot(z, z)
-
+def roundToDigit(x, p):
+    """Round a real number to the specified number of significant digits."""
+    if not x:
+        return x
+    k = np.int(np.floor(np.log10(np.abs(x)))) + (p-1)
+    r = np.around(x, -k)
+    if int(r) == r:
+        return int(r)
+    else:
+        return r
 
 def precision(x, p, vrange=None, delimiter='e'):
     """
     Returns a string representation of `x` formatted with precision `p`.
 
-    :param float vrange: range in which x exists (to snap it to '0' if below precision).
-
-    Based on the webkit javascript implementation taken
-    `from here <https://code.google.com/p/webkit-mirror/source/browse/JavaScriptCore/kjs/number_object.cpp>`_,
-    and implemented by `randlet <https://github.com/randlet/to-precision>`_.
+    :param float vrange: range in which x exists (to snap x to '0' if below precision).
     """
-    #round_to_n = lambda x, n: np.around(x, -np.int(np.floor(np.log10(np.abs(x)))) + (n - 1))
-    #x= 13556.783434
-    #print(round_to_n(x, 3))
-    #print(precision(x, 3))
+    # Based on the webkit javascript implementation
+    # `from here <https://code.google.com/p/webkit-mirror/source/browse/JavaScriptCore/kjs/number_object.cpp>`_,
+    # and implemented by `randlet <https://github.com/randlet/to-precision>`_.
 
     if isinstance(x, str): #do nothing
         return x
@@ -612,8 +689,12 @@ def precision(x, p, vrange=None, delimiter='e'):
         nn=len(x)-1
         for i, ix in enumerate(x):
 
-            if np.isnan(ix):
-                return "NaN"
+            try:
+                if np.isnan(ix):
+                    return "NaN"
+            except:
+                # cannot handle list of list
+                continue
 
             out += precision(ix, p)
             if i<nn: out += ', '
@@ -674,20 +755,20 @@ def precision(x, p, vrange=None, delimiter='e'):
 
 # 2d
 def cart2pol(x, y):
-    """Cartesian to Polar coordinates conversion."""
+    """2D Cartesian to Polar coordinates conversion."""
     theta = np.arctan2(y, x)
     rho = np.hypot(x, y)
     return rho, theta
 
 def pol2cart(rho, theta):
-    """Polar to Cartesian coordinates conversion."""
+    """2D Polar to Cartesian coordinates conversion."""
     x = rho * np.cos(theta)
     y = rho * np.sin(theta)
     return x, y
 
 # 3d
 def cart2spher(x, y, z):
-    """Cartesian to Spherical coordinate conversion."""
+    """3D Cartesian to Spherical coordinate conversion."""
     hxy = np.hypot(x, y)
     rho = np.hypot(hxy, z)
     #if not rho:
@@ -697,7 +778,7 @@ def cart2spher(x, y, z):
     return rho, theta, phi
 
 def spher2cart(rho, theta, phi):
-    """Spherical to Cartesian coordinate conversion."""
+    """3D Spherical to Cartesian coordinate conversion."""
     st = np.sin(theta)
     sp = np.sin(phi)
     ct = np.cos(theta)
@@ -709,21 +790,25 @@ def spher2cart(rho, theta, phi):
     return np.array([x, y, z])
 
 def cart2cyl(x,y,z):
+    """3D Cartesian to Cylindrical coordinate conversion."""
     rho = np.sqrt(x*x+y*y+z*z)
     theta = np.arctan2(y, x)
     return rho, theta, z
 
 def cyl2cart(rho, theta, z):
+    """3D Cylindrical to Cartesian coordinate conversion."""
     x = rho * np.cos(theta)
     y = rho * np.sin(theta)
-    return x, y, z
+    return np.array([x, y, z])
 
 def cyl2spher(rho,theta,z):
+    """3D Cylindrical to Spherical coordinate conversion."""
     rhos = np.sqrt(rho*rho+z*z)
     phi = np.arctan2(rho, z)
     return rhos, theta, phi
 
 def spher2cyl(rho, theta, phi):
+    """3D Spherical to Cylindrical coordinate conversion."""
     rhoc = rho * np.sin(phi)
     z = rho * np.cos(phi)
     return rhoc, theta, z
@@ -754,7 +839,7 @@ def grep(filename, tag, firstOccurrence=False):
 def printInfo(obj):
     """Print information about a vtk object."""
 
-
+    ################################
     def printvtkactor(actor, tab=""):
 
         if not actor.GetPickable():
@@ -779,9 +864,9 @@ def printInfo(obj):
         npl = poly.GetNumberOfPolys()
 
         print(tab, end="")
-        printc("Mesh", c="g", bold=1, invert=1, dim=1, end=" ")
+        printc("Mesh/Points", c="g", bold=1, invert=1, dim=1, end=" ")
 
-        if 'legend' in actor.info.keys() and actor.info['legend']:
+        if hasattr(actor, "info") and 'legend' in actor.info.keys() and actor.info['legend']:
             printc("legend: ", c="g", bold=1, end="")
             printc(actor.info['legend'], c="g", bold=0)
         else:
@@ -861,7 +946,7 @@ def printInfo(obj):
         bz1, bz2 = precision(bnds[4], 3), precision(bnds[5], 3)
         printc(" z=(" + bz1 + ", " + bz2 + ")", c="g", bold=0)
 
-        if actor.picked3d is not None:
+        if hasattr(actor, "picked3d") and actor.picked3d is not None:
             printc(tab + "  clicked point: ", c="g", bold=1, end="")
             printc(vector(actor.picked3d), c="g", bold=0)
 
@@ -923,16 +1008,47 @@ def printInfo(obj):
             printc('no point or cell scalars are present.', c="g", bold=0)
 
 
-    if not obj:
+    if obj is None:
         return
 
-    elif isinstance(obj, vtk.vtkActor):
+    elif isinstance(obj, np.ndarray):
+        A = obj
+        cf = "y"
+        printc("_" * 65, c=cf, bold=0)
+        printc("Numpy array", c=cf, invert=1)
+        printc(A, c=cf)
+        printc("shape   =", A.shape, c=cf)
+        printc("range   =", np.min(A), "->", np.max(A), c=cf)
+        printc("min(abs)=", np.min(np.abs(A)), c=cf)
+        printc("mean \t=", np.mean(A), c=cf)
+        printc("std_dev\t=", np.std(A), c=cf)
+        if len(A.shape) >= 2:
+            printc("AXIS 0:", c=cf, italic=1)
+            printc("\tmin =", np.min(A, axis=0), c=cf)
+            printc("\tmax =", np.max(A, axis=0), c=cf)
+            printc("\tmean=", np.mean(A, axis=0), c=cf)
+            if A.shape[1] >3 :
+                printc("AXIS 1:", c=cf, italic=1)
+                printc("\tmin =",
+                    str(np.min(A, axis=1).tolist()[:2]).replace("]", ", ..."),
+                    c=cf,
+                )
+                printc("\tmax =",
+                    str(np.max(A, axis=1).tolist()[:2]).replace("]", ", ..."),
+                    c=cf,
+                )
+                printc("\tmean=",
+                    str(np.mean(A, axis=1).tolist()[:2]).replace("]", ", ..."),
+                    c=cf,
+                )
+
+    elif isinstance(obj, vedo.Points):
         printc("_" * 65, c="g", bold=0)
         printvtkactor(obj)
 
-    elif isinstance(obj, vtk.vtkAssembly):
+    elif isinstance(obj, vedo.Assembly):
         printc("_" * 65, c="g", bold=0)
-        printc("vtkAssembly", c="g", bold=1, invert=1)
+        printc("Assembly", c="g", bold=1, invert=1)
 
         pos = obj.GetPosition()
         bnds = obj.GetBounds()
@@ -955,12 +1071,28 @@ def printInfo(obj):
             if isinstance(act, vtk.vtkActor):
                 printvtkactor(act, tab="     ")
 
-    # elif isinstance(obj, vedo.TetMesh):
-    #     return # todo
+    elif isinstance(obj, vedo.TetMesh):
+        cf='m'
+        printc("_" * 65, c=cf, bold=0)
+        printc("TetMesh", c=cf, bold=1, invert=1)
+        pos = obj.GetPosition()
+        bnds = obj.GetBounds()
+        ug = obj._data
+        printc("    nr. of tetras: ", c=cf, bold=1, end="")
+        printc(ug.GetNumberOfCells(), c=cf, bold=0)
+        printc("         position: ", c=cf, bold=1, end="")
+        printc(pos, c=cf, bold=0)
+        printc("           bounds: ", c=cf, bold=1, end="")
+        bx1, bx2 = precision(bnds[0], 3), precision(bnds[1], 3)
+        printc("x=(" + bx1 + ", " + bx2 + ")", c=cf, bold=0, end="")
+        by1, by2 = precision(bnds[2], 3), precision(bnds[3], 3)
+        printc(" y=(" + by1 + ", " + by2 + ")", c=cf, bold=0, end="")
+        bz1, bz2 = precision(bnds[4], 3), precision(bnds[5], 3)
+        printc(" z=(" + bz1 + ", " + bz2 + ")", c=cf, bold=0)
 
-    elif isinstance(obj, vtk.vtkVolume):
+    elif isinstance(obj, vedo.Volume):
         printc("_" * 65, c="b", bold=0)
-        printc("vtkVolume", c="b", bold=1, invert=1)
+        printc("Volume", c="b", bold=1, invert=1)
 
         pos = obj.GetPosition()
         bnds = obj.GetBounds()
@@ -976,7 +1108,7 @@ def printInfo(obj):
         printc(img.GetDataDimension(), c="b", bold=0)
 
         printc("      memory size: ", c="b", bold=1, end="")
-        printc(int(img.GetActualMemorySize()/1024), 'Mb', c="b", bold=0)
+        printc(int(img.GetActualMemorySize()/1024), 'MB', c="b", bold=0)
 
         printc("    scalar #bytes: ", c="b", bold=1, end="")
         printc(img.GetScalarSize(), c="b", bold=0)
@@ -995,7 +1127,7 @@ def printInfo(obj):
         printHistogram(obj, horizontal=True,
                        logscale=True, bins=8, height=15, c='b', bold=0)
 
-    elif hasattr(obj, "interactor"):  # dumps Plotter info
+    elif isinstance(obj, vedo.Plotter) and obj.interactor:  # dumps Plotter info
         axtype = {
             0: "(no axes)",
             1: "(three customizable gray grid walls)",
@@ -1021,7 +1153,6 @@ def printInfo(obj):
                 bns.append(b)
         if len(bns) == 0:
             return
-        acts = obj.getMeshes()
         printc("_" * 65, c="c", bold=0)
         printc("Plotter", invert=1, dim=1, c="c", end=" ")
         otit = obj.title
@@ -1031,7 +1162,7 @@ def printInfo(obj):
         printc("     window size:", obj.window.GetSize(),
                "- full screen size:", obj.window.GetScreenSize(), bold=0, c="c")
         printc(" active renderer:", obj.renderers.index(obj.renderer), bold=0, c="c")
-        printc("   nr. of actors:", len(acts), bold=0, c="c", end="")
+        printc("   nr. of actors:", len(obj.actors), bold=0, c="c", end="")
         printc(" (" + str(totpt), "vertices)", bold=0, c="c")
         max_bns = np.max(bns, axis=0)
         min_bns = np.min(bns, axis=0)
@@ -1064,9 +1195,36 @@ def printInfo(obj):
 
         printc(" Click mesh and press i for info.", c="c")
 
+    elif isinstance(obj, vedo.Picture):  # dumps Plotter info
+        printc("_" * 65, c="y", bold=0)
+        printc("Picture", c="y", bold=1, invert=1)
+
+        pos = obj.GetPosition()
+        bnds = obj.GetBounds()
+        img = obj.GetMapper().GetInput()
+        printc("         position: ", c="y", bold=1, end="")
+        printc(pos, c="y", bold=0)
+
+        printc("       dimensions: ", c="y", bold=1, end="")
+        printc(obj.shape, c="y", bold=0)
+
+        printc("      memory size: ", c="y", bold=1, end="")
+        printc(int(img.GetActualMemorySize()), 'kB', c="y", bold=0)
+
+        printc("           bounds: ", c="y", bold=1, end="")
+        bx1, bx2 = precision(bnds[0], 3), precision(bnds[1], 3)
+        printc("x=(" + bx1 + ", " + bx2 + ")", c="y", bold=0, end="")
+        by1, by2 = precision(bnds[2], 3), precision(bnds[3], 3)
+        printc(" y=(" + by1 + ", " + by2 + ")", c="y", bold=0, end="")
+        bz1, bz2 = precision(bnds[4], 3), precision(bnds[5], 3)
+        printc(" z=(" + bz1 + ", " + bz2 + ")", c="y", bold=0)
+
+        printc("     scalar range: ", c="y", bold=1, end="")
+        printc(img.GetScalarRange(), c="y", bold=0)
+
     else:
-        printc("_" * 65, c="g", bold=0)
-        printc(type(obj), c="g", invert=1)
+        printc(type(obj), invert=1)
+        printc(obj)
 
 
 
@@ -1100,7 +1258,8 @@ def printHistogram(data, bins=10, height=10, logscale=False, minbin=0,
 
         |printhisto|
     """
-    # Adapted from http://pyinsci.blogspot.com/2009/10/ascii-histograms.html
+    # credits: http://pyinsci.blogspot.com/2009/10/ascii-histograms.html
+    # adapted for vedo by M.Musy, 2019
 
     if not horizontal: # better aspect ratio
         bins *= 2
@@ -1126,8 +1285,7 @@ def printHistogram(data, bins=10, height=10, logscale=False, minbin=0,
             if not arr:
                 return
 
-        from vtk.util.numpy_support import vtk_to_numpy
-        data = vtk_to_numpy(arr)
+        data = vtk2numpy(arr)
 
     h = np.histogram(data, bins=bins)
 
@@ -1365,6 +1523,8 @@ def makeTicks(x0, x1, N, labels=None, digits=None):
             if upBound<0:
                 negaxis = np.arange(lowBound, int(upBound/s)*s)
             else:
+                if -lowBound/s > 1.0e+06:
+                    return np.array([0.0,1.0]), ["",""]
                 negaxis = np.arange(lowBound, 0, s)
         else:
             negaxis = np.array([])
@@ -1373,6 +1533,8 @@ def makeTicks(x0, x1, N, labels=None, digits=None):
             if lowBound>0:
                 posaxis = np.arange(int(lowBound/s)*s, upBound, s)
             else:
+                if upBound/s > 1.0e+06:
+                    return np.array([0.0,1.0]), ["",""]
                 posaxis = np.arange(0, upBound, s)
         else:
             posaxis = np.array([])
@@ -1413,6 +1575,55 @@ def makeTicks(x0, x1, N, labels=None, digits=None):
     return ticks_float, ticks_str
 
 
+def gridcorners(i, nm, size, margin=0, flipy=True):
+    """
+    Compute the 2 corners of the i-th box of a grid n*m.
+    The bottom-left square is number 1.
+
+    Parameters
+    ----------
+    i : int
+        input index of the desired grid square (to be used in ``show(..., at=...)``).
+    nm : list
+        grid shape as (n,m).
+    size : list
+        total size of the grid along x and y.
+    margin : float, optional
+        keep a small margin between boxes. The default is 0.
+    flipy : bool, optional
+        y-coordinate points downwards
+
+    Returns
+    -------
+    Two 2D points representing the bottom-left corner and the top-right corner
+    of the ``i``-nth box in the grid.
+
+    :Example:
+        .. code-block:: python
+
+            from vedo import *
+            acts=[]
+            n,m = 5,7
+            for i in range(1, n*m + 1):
+                c1,c2 = utils.gridcorners(i, [n,m], [1,1], 0.01)
+                t = Text3D(i, (c1+c2)/2, c='k', s=0.02, justify='center').z(0.01)
+                r = Rectangle(c1, c2, c=i)
+                acts += [t,r]
+            show(acts, axes=1)
+    """
+    i -= 1
+    n,m = nm
+    sx,sy = size
+    dx, dy = sx/n, sy/m
+    nx = i%n
+    ny = int((i-nx)/n)
+    if flipy:
+        ny = n - ny
+    c1 = (dx*nx + margin, dy*ny + margin)
+    c2 = (dx*(nx+1) - margin, dy*(ny+1) - margin)
+    return np.array(c1), np.array(c2)
+
+
 ############################################################################
 #Trimesh support
 #
@@ -1556,9 +1767,9 @@ def meshlab2vedo(mmesh):
     else:
         polydata = buildPolyData(mpoints, None)
     if len(pnorms):
-        polydata.GetPointData().SetNormals(numpy_to_vtk(pnorms, deep=True))
+        polydata.GetPointData().SetNormals(numpy2vtk(pnorms))
     if len(cnorms):
-        polydata.GetCellData().SetNormals(numpy_to_vtk(cnorms, deep=True))
+        polydata.GetCellData().SetNormals(numpy2vtk(cnorms))
     return polydata
 
 
@@ -1585,30 +1796,6 @@ def vtkVersionIsAtLeast(major, minor=0, build=0):
     else:
         return False
 
-# def systemReport():
-#     try:
-#         import scooby
-#         r = scooby.Report(additional=['vtk',
-#                                       'vedo',
-#                                       'meshio',
-#                                       'matplotlib',
-#                                       'k3d',
-#                                       'itkwidgets',
-#                                       'panel',
-#                                       'dolfin',
-#                                       'trimesh',
-#                                       'pymeshfix',
-#                                       'pygmsh',
-#                                       'nevergrad',
-#                                       'pyshtools',
-#                                       'cv2',
-#                                       ])
-#         printc(r)
-#     except:
-#         print('Install scooby with command: pip install scooby')
-#         r = ''
-#     return r
-
 
 def ctf2lut(tvobj):
     # build LUT from a color transfer function for tmesh or volume
